==> speakrec-0.1.4.tar.gz: speakrec-0.1.4/tapeboxtest.cpp <==
/*
 * Speak Recorder
 * Copyright  2003 by Schou Industries ApS.
 */

#include <stdio.h>
#include "speakrec.h"
#include "tapebox.h"

#define DELAY 500000*1

using namespace std;

int opt_keylayout = 0;

char *binary(char *buf, int value) {
	int i = 0;

	while (i<8) {
		buf[i] = value & (1<<(7-i)) ? '1' : '0';
		i++;
	}
	buf[i] = '\0';

	return buf;
}

unsigned char hextobin(char v) {
	unsigned char data = 0;

	if (v > '9') {
		data = v-'a'+10;
	} else {
		data = v-'0';
	}

	return data;
}

int main(int argc, char **argv ) {
	long i;
	int n;
	char temp[10];
	unsigned char addr = 0;
	unsigned char data = 0;

	if (argc < 2) {
		printf("commandline device missing\n");
		printf("Usage:\n");
		printf("\t%s/dev/usb/tts/0 [addr data]\n", argv[0]);
		printf("\t%s/dev/ttyUSB0\n", argv[0]);
		exit(1);
	}
	printf("Open device: %s\n", argv[1]);

	TapeboxConsole term(argv[1]);
	printf("Name of device %d: %s\n", term.fd, term.nameofdevice);

	if (term.fd > 0) {
		for (n=0; n<0x0F; n++) {
			term.senddata(n,0x00);
		}
		if (argc>3) {
			addr = atoi(argv[2]);
			strncpy(temp, argv[3], sizeof(temp)-1);
			switch (strlen(temp)) {
				case 1:
				case 2:
				case 3:
					data = atoi(temp);
					break;
				case 4:
					if (temp[1] == 'x') {
						data = (hextobin(temp[2]) << 4) | hextobin(temp[3]);
					}
					break;
				case 8:
					n = 0;
					while (n<8) {
						if (temp[n] == '1') {
							data |= 1 << (7-n);
						}
						n++;
					}
					break;

			}
			printf("addr: %d, data: %d 0x%02x %s\n", addr, data, data & 0xFF, binary(temp,data));
			term.senddata(addr, data);
		} else {
			for (n=0; n<0x08; n++) {
				term.senddata(n, 1 << n);
			}
			term.senddata(0x0A, ~0xF0);
			term.senddata(0x0B, ~0x0F);
			term.senddata(0x09, 7);
		}
	}

	return 0;
}

==> speakrec-0.1.6.tar.gz: speakrec-0.1.6/tapeboxtest.cpp <==
/*
 * Speak Recorder
 * Copyright  2003 by Schou Industries ApS.
 */

#include <stdio.h>
#include "speakrec.h"
#include "tapebox.h"

#define DELAY 500000*1

using namespace std;

int opt_keylayout = 0;

char *binary(char *buf, int value) {
	int i = 0;

	while (i<8) {
		buf[i] = value & (1<<(7-i)) ? '1' : '0';
		i++;
	}
	buf[i] = '\0';

	return buf;
}

unsigned char hextobin(char v) {
	unsigned char data = 0;

	if (v > '9') {
		data = v-'a'+10;
	} else {
		data = v-'0';
	}

	return data;
}

int main(int argc, char **argv ) {
	int n;
	char temp[10];
	unsigned char addr = 0;
	unsigned char data = 0;

	if (argc < 2) {
		printf("commandline device missing\n");
		printf("Usage:\n");
		printf("\t%s/dev/usb/tts/0 [addr data]\n", argv[0]);
		printf("\t%s/dev/ttyUSB0\n", argv[0]);
		exit(1);
	}
	printf("Open device: %s\n", argv[1]);

	TapeboxConsole term(argv[1]);
	printf("Name of device %d: %s\n", term.fd, term.nameofdevice);

	if (term.fd > 0) {
		for (n=0; n<0x0F; n++) {
			term.senddata(n,0x00);
		}
		if (argc>3) {
			addr = atoi(argv[2]);
			strncpy(temp, argv[3], sizeof(temp)-1);
			switch (strlen(temp)) {
				case 1:
				case 2:
				case 3:
					data = atoi(temp);
					break;
				case 4:
					if (temp[1] == 'x') {
						data = (hextobin(temp[2]) << 4) | hextobin(temp[3]);
					}
					break;
				case 8:
					n = 0;
					while (n<8) {
						if (temp[n] == '1') {
							data |= 1 << (7-n);
						}
						n++;
					}
					break;

			}
			printf("addr: %d, data: %d 0x%02x %s\n", addr, data, data & 0xFF, binary(temp,data));
			term.senddata(addr, data);
		} else {
			for (n=0; n<0x08; n++) {
				term.senddata(n, 1 << n);
			}
			term.senddata(0x0A, (unsigned char)~0xF0);
			term.senddata(0x0B, ~0x0F);
			term.senddata(0x09, 7);
		}
	}

	return 0;
}
